.. currentmodule:: plopp

******************
Matplotlib backend
******************

.. autosummary::
   :toctree: generated

   backends.matplotlib.MatplotlibBackend
   backends.matplotlib.canvas.Canvas
   backends.matplotlib.line.Line
   backends.matplotlib.image.Image
   backends.matplotlib.static.StaticFig
   backends.matplotlib.interactive.InteractiveFig
